@@ -6,7 +6,7 @@ from dataclasses import dataclass
 
 import jax
 
-from .tree_base import treeBase
+from .tree_base import explicitTreeBase, implicitTreeBase, treeBase
 from .tree_indexer import treeIndexer
 from .tree_op_base import treeOpBase
 
@@ -14,7 +14,7 @@ from .tree_op_base import treeOpBase
 def treeclass(*args, **kwargs):
     """Class JAX  compaitable decorator for `dataclass`"""
 
-    def wrapper(cls, op: bool = True):
+    def wrapper(cls, op: bool, field_only: bool):
         user_defined_init = "__init__" in cls.__dict__
 
         dCls = dataclass(
@@ -23,14 +23,16 @@ def treeclass(*args, **kwargs):
 
         base_classes = (dCls, treeBase)
         base_classes += (treeOpBase, treeIndexer) if op else ()
+        base_classes += (explicitTreeBase,) if field_only else (implicitTreeBase,)
 
         newCls = type(cls.__name__, base_classes, {})
 
         return jax.tree_util.register_pytree_node_class(newCls)
 
     if len(args) > 0 and inspect.isclass(args[0]):
-        return wrapper(args[0], True)
+        return wrapper(args[0], True, False)
 
     elif len(args) == 0 and len(kwargs) > 0:
-        op = kwargs["op"] if "op" in kwargs else False
-        return functools.partial(wrapper, op=op)
+        op = kwargs["op"] if "op" in kwargs else True
+        field_only = kwargs["field_only"] if "field_only" in kwargs else False
+        return functools.partial(wrapper, op=op, field_only=field_only)
