@@ -9,9 +9,9 @@ import requests
 from jax import tree_flatten
 
 from .tree_util import (
+    _reduce_count_and_size,
     is_treeclass,
     is_treeclass_leaf,
-    _reduce_count_and_size,
     sequential_model_shape_eval,
 )
 
@@ -290,7 +290,11 @@ def _summary_str(model, array=None, render: str = "string") -> str:
     if array is not None:
         params_shape = sequential_model_shape_eval(model, array)[1:]
 
-    for index, leaf in enumerate(model.treeclass_leaves):
+    # all dynamic/static leaves
+    all_leaves = (*model.tree_fields[0].values(), *model.tree_fields[1].values())
+    treeclass_leaves = [leaf for leaf in all_leaves if is_treeclass(leaf)]
+
+    for index, leaf in enumerate(treeclass_leaves):
         name, count, size = _summary_line(leaf)
 
         shape = _node_format(params_shape[index]) if array is not None else ""
@@ -313,7 +317,9 @@ def _summary_str(model, array=None, render: str = "string") -> str:
                 [f"{k}={_node_format(v)}" for k, v in leaf.tree_fields[0].items()]
             )
 
-        ROW += [[name, _format_count(count, True), _format_size(size, True), fmt, shape]]
+        ROW += [
+            [name, _format_count(count, True), _format_size(size, True), fmt, shape]
+        ]
 
     COL = [list(c) for c in zip(*ROW)]
     if array is None:
@@ -359,7 +365,11 @@ def _summary_md(model, array=None) -> str:
     if array is not None:
         params_shape = sequential_model_shape_eval(model, array)[1:]
 
-    for index, leaf in enumerate(model.treeclass_leaves):
+    # all dynamic/static leaves
+    all_leaves = (*model.tree_fields[0].values(), *model.tree_fields[1].values())
+    treeclass_leaves = [leaf for leaf in all_leaves if is_treeclass(leaf)]
+
+    for index, leaf in enumerate(treeclass_leaves):
         name, count, size = _summary_line(leaf)
 
         shape = _node_format(params_shape[index]) if array is not None else ""
@@ -626,6 +636,7 @@ def tree_mermaid(model, link=False):
             nonlocal fmt
 
             if is_treeclass(model):
+                is_frozen = model.frozen
 
                 for i, field in enumerate(model.__dataclass_fields__.values()):
                     cur_node = model.__dict__[field.name]
@@ -645,7 +656,9 @@ def tree_mermaid(model, link=False):
                         is_static = (
                             "static" in field.metadata and field.metadata["static"]
                         )
-                        connector = "-.-" if is_static else "---"
+                        connector = (
+                            "--x" if is_static else ("-.-" if is_frozen else "---")
+                        )
                         fmt += f'\tid{prev_id} {connector} id{cur_id}["{field.name}\\n{_node_format(cur_node)}"]'
                         recurse(cur_node, cur_depth + 1, cur_id)
 
