@@ -35,7 +35,41 @@ def test_getter_by_param():
     assert is_treeclass_equal(B, Test(10, 20, 30, jnp.array([1, 2, 3, 4, 5]), "A"))
 
 
-def test_getter_by_model():
+def test_getter_by_slice():
+    A = Test(10, 20, 30, jnp.array([1, 2, 3, 4, 5]), "A")
+
+    B = A.at[0:1].get()
+    assert is_treeclass_equal(B, Test(10, None, None, None, "A"))
+
+    B = A.at[0:2].get()
+    assert is_treeclass_equal(B, Test(10, 20, None, None, "A"))
+
+    B = A.at[:-1].get()
+    assert is_treeclass_equal(B, Test(10, 20, 30, None, "A"))
+
+    B = A.at[:].get()
+    assert is_treeclass_equal(B, Test(10, 20, 30, jnp.array([1, 2, 3, 4, 5]), "A"))
+
+
+def test_getter_by_int():
+    A = Test(10, 20, 30, jnp.array([1, 2, 3, 4, 5]), "A")
+
+    B = A.at[0].get()
+    assert is_treeclass_equal(B, Test(10, None, None, None, "A"))
+
+    B = A.at[1].get()
+    assert is_treeclass_equal(B, Test(None, 20, None, None, "A"))
+
+    B = A.at[2].get()
+    assert is_treeclass_equal(B, Test(None, None, 30, None, "A"))
+
+    B = A.at[3].get()
+    assert is_treeclass_equal(
+        B, Test(None, None, None, jnp.array([1, 2, 3, 4, 5]), "A")
+    )
+
+
+def test_getter_by_pytree():
     @treeclass
     class level1:
         a: int
@@ -71,8 +105,8 @@ def test_getter_by_model():
     with pytest.raises(ValueError):
         B = A.at[A].get()
 
-    with pytest.raises(NotImplementedError):
-        B = A.at[0].get()
+    # with pytest.raises(NotImplementedError):
+    B = A.at[0].get()
 
 
 def test_setter_by_param():
@@ -88,7 +122,33 @@ def test_setter_by_param():
     assert is_treeclass_equal(B, Test(0, 0, 0, jnp.array([1, 2, 3, 4, 5]), "A"))
 
 
-def test_setter_by_model():
+def test_setter_by_slice():
+    A = Test(10, 20, 30, jnp.array([1, 2, 3, 4, 5]), "A")
+
+    B = A.at[0:1].set(0)
+    assert is_treeclass_equal(B, Test(0, 20, 30, jnp.array([1, 2, 3, 4, 5]), "A"))
+
+    B = A.at[0:2].set(0)
+    assert is_treeclass_equal(B, Test(0, 0, 30, jnp.array([1, 2, 3, 4, 5]), "A"))
+
+    B = A.at[0:3].set(0)
+    assert is_treeclass_equal(B, Test(0, 0, 0, jnp.array([1, 2, 3, 4, 5]), "A"))
+
+
+def test_setter_by_int():
+    A = Test(10, 20, 30, jnp.array([1, 2, 3, 4, 5]), "A")
+
+    B = A.at[0].set(0)
+    assert is_treeclass_equal(B, Test(0, 20, 30, jnp.array([1, 2, 3, 4, 5]), "A"))
+
+    B = A.at[1].set(0)
+    assert is_treeclass_equal(B, Test(10, 0, 30, jnp.array([1, 2, 3, 4, 5]), "A"))
+
+    B = A.at[2].set(0)
+    assert is_treeclass_equal(B, Test(10, 20, 0, jnp.array([1, 2, 3, 4, 5]), "A"))
+
+
+def test_setter_by_pytree():
     @treeclass
     class level1:
         a: int
@@ -118,8 +178,8 @@ def test_setter_by_model():
     with pytest.raises(ValueError):
         B = A.at[A].set(0)
 
-    with pytest.raises(NotImplementedError):
-        B = A.at[0].set(0)
+    # with pytest.raises(NotImplementedError):
+    B = A.at[0].set(0)
 
 
 def test_apply_and_its_derivatives():
@@ -131,6 +191,7 @@ def test_apply_and_its_derivatives():
 
     init = A(1, 2, jnp.array([1, 2, 3, 4, 5]))
 
+    # By boolean pytree
     lhs = A(1, 4, jnp.array([1, 4, 9, 16, 25]))
     rhs = init.at[init == init].apply(lambda x: x**2)
     assert is_treeclass_equal(lhs, rhs)
@@ -163,6 +224,21 @@ def test_apply_and_its_derivatives():
     rhs = init.at[init == init].power(2)
     assert is_treeclass_equal(lhs, rhs)
 
+    lhs = A(1, 2, jnp.array([1, 2, 3, 16, 25]))
+    rhs = init.at[init > 3].apply(lambda x: x**2)
+    assert is_treeclass_equal(lhs, rhs)
+
+    lhs = A(2, 3, jnp.array([2, 3, 4, 5, 6]))
+    rhs = init.at[init > 0].apply(lambda x: x + 1)
+    assert is_treeclass_equal(lhs, rhs)
+
+    rhs = init.at[init > 100].apply(lambda x: (x + 1) * 10)
+    assert is_treeclass_equal(init, rhs)
+
+    lhs = A(2, 3, jnp.array([2, 3, 4, 5, 6]))
+    rhs = init.at[init > 0].add(1)
+    assert is_treeclass_equal(lhs, rhs)
+
     # by param
 
     lhs = A(1, 2, jnp.array([1, 2, 3, 4, 5]))
@@ -196,3 +272,24 @@ def test_apply_and_its_derivatives():
     lhs = A(1, 2, jnp.array([1, 2, 3, 4, 5]))
     rhs = init.at["a"].power(2)
     assert is_treeclass_equal(lhs, rhs)
+
+    # by param
+    with pytest.raises(ValueError):
+        init.freeze().at["a"].apply(lambda x: x**2)
+
+    with pytest.raises(ValueError):
+        init.freeze().at["a", "b"].apply(lambda x: x**2)
+
+    # by slice
+    with pytest.raises(ValueError):
+        init.freeze().at[:].apply(lambda x: x**2)
+
+    with pytest.raises(ValueError):
+        init.freeze().at[0].apply(lambda x: x**2)
+
+    # by pytree
+    with pytest.raises(ValueError):
+        init.freeze().at[init > 1].apply(lambda x: x**2)
+
+    with pytest.raises(ValueError):
+        init.freeze().at[init == 1].apply(lambda x: x**2)
